## dbt-redshift 1.9.1 - March 07, 2025

### Features

- Add 'is_serverless' param to profile and connection calls ([#819](https://github.com/dbt-labs/dbt-adapters/issues/819))

### Under the Hood

- Handle Gracefully handle null result from backend_pid check ([#821](https://github.com/dbt-labs/dbt-adapters/issues/821))
